#
# spec file for package dwarfs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover %(echo %{version} | sed 's/\\./_/g;')
%define __builder ninja
Name:           dwarfs
Version:        0.12.3
Release:        1.2
Summary:        Deduplicating compressed read-only file system
License:        GPL-3.0-or-later AND MIT
URL:            https://github.com/mhx/dwarfs
Source0:        https://github.com/mhx/dwarfs/releases/download/v%{version}/dwarfs-%{version}.tar.xz
BuildRequires:  bison
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  libboost_chrono-devel
BuildRequires:  libboost_context-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_process-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  ninja
BuildRequires:  parallel-hashmap-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(date)
BuildRequires:  cmake(double-conversion)
BuildRequires:  cmake(range-v3)
BuildRequires:  cmake(utf8cpp)
BuildRequires:  pkgconfig(benchmark)
BuildRequires:  pkgconfig(clzma)
BuildRequires:  pkgconfig(flac++)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(fuse3)
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(libacl)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libbrotlicommon)
BuildRequires:  pkgconfig(libdwarf)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libglog)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libmagic)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(libunwind)
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(nlohmann_json)

%description
The Deduplicating Warp-speed Advanced Read-only File System.

DwarFS is a deduplicating compressed read-only file system
particularly suited for very redundant data.
Compared to SquashFS, it is typically more efficient.

%package -n libdwarfs%{sover}
Summary:        DwarFS dynamic library

%description -n libdwarfs%{sover}
The Deduplicating Warp-speed Advanced Read-only File System.

DwarFS is a deduplicating compressed read-only file system
particularly suited for very redundant data.
Compared to SquashFS, it is typically more efficient.

This package contains the dynamic library for DwarFS.

%package devel
Summary:        DwarFS development files
Requires:       libdwarfs%{sover} = %{version}

%description devel
The Deduplicating Warp-speed Advanced Read-only File System.

DwarFS is a deduplicating compressed read-only file system
particularly suited for very redundant data.
Compared to SquashFS, it is typically more efficient.

This package contains the development files for DwarFS.

%ldconfig_scriptlets -n libdwarfs%{sover}

%prep
%autosetup -p1

%build
%cmake \
    -DCMAKE_EXE_LINKER_FLAGS="-lboost_system -lboost_filesystem -lboost_process"
%cmake_build

%install
%cmake_install

# only mount helper should be in sbin
mv %{buildroot}%{_sbindir}/dwarfs %{buildroot}%{_bindir}/dwarfs
ln -sf %{_bindir}/dwarfs %{buildroot}%{_sbindir}/mount.dwarfs

%files
%license LICENSE
%doc README.md

%{_mandir}/*/*dwarfs*
%{_bindir}/*dwarfs*
%{_sbindir}/mount.dwarfs

%files -n libdwarfs%{sover}
%{_libdir}/*.so.*

%files devel
%{_includedir}/dwarfs
%{_libdir}/cmake/dwarfs
%{_libdir}/libdwarfs*.so

%changelog
* Mon Apr 21 2025 Mia Herkt <mia@0x0.st>
- Update to version 0.12.3:
  Bugfixes
  * Automatic image offset detection (for images using a custom
    header) did not work correctly if the header contained a
    string that would be identified as the start of a v1 section
    header (these were only used before dwarfs-0.3.0).
    If there was either "DWARFS\x02\x00" or "DWARFS\x02\x01" in
    the header, offset detection would fail. The check has been
    modified to peek further into the data and ensure this really
    is a v1 section header, and also checking if the next section
    header position can be derived from the length field.
    It is still possible to construct a file system image where
    offset detection will ultimately fail, but it is much less
    likely with the change.
- Changes in version 0.12.2:
  Bugfixes
  * The dwarfs-0.12.0 release introduced a performance regression
  where FLAC compression took more than twice as long as in the
  previous releases. This has been fixed. FLAC decompression was
  unaffected.
* Sun Apr 13 2025 Mia Herkt <mia@0x0.st>
- Update to version 0.12.1:
  Features
  * Added --memory-limit=auto to mkdwarfs to use a more reasonable
    (hopefully) default for the block queue. The old default of
    1 GiB was quite arbitrary and definitely not suitable for
    low-end systems. The new auto default will determine the limit
    based on the number of workers (which in turn is based on the
    number of CPUs), the block size, and the amount of physical
    memory of the system.
  * Replaced vector_byte_buffer with malloc_byte_buffer, which is
    internally based around a simple buffer that doesn't incur the
    cost of initializing each element like std::vector. Especially
    for large blocks which are known to be overwritten immediately,
    this can save a few CPU cycles.
- Changes in version 0.12.0:
  * New Licensing Conditions: Instead of being all GPL-3.0 like all
    the previous releases, this release changes the license of a
    large fraction of the DwarFS code to MIT. All tools and
    libraries that only read DwarFS images are now MIT-licensed.
    Everything else (e.g. mkdwarfs) is still GPL-3.0 for the time
    being.
  Bugfixes
  * Changes for compatibility with Boost.Process v2.
  Features
  * Re-licensed all libraries required for reading DwarFS images
    under the MIT license. The source of all tools that just read
    DwarFS images (i.e. everything except for mkdwarfs) are also
    under the MIT license now. Everything else is still GPL-3.0.
    gh#mhx/dwarfs#255
  * New hotness categorizer in mkdwarfs that allows a list of "hot"
    files to be stored in distinct file system blocks.
  * New explicit ordering mode in mkdwarfs that allows files to be
    ordered accoring to the order in a given list file.
  * dwarfs now shows the version of the FUSE library used.
  * New dwarfs options preload_all and preload_category to populate
    the block cache immediately after mounting.
  * New dwarfs option analysis_file that can be used for profiling
    and as input to mkdwarfs new hotness categorizer and explicit
    ordering mode.
  * New dwarfs option block_allocator that allows the user to
    switch from a malloc-based block allocator to an mmap-based
    one. This can help with returning memory back to the system if
    the blocks are evicted from the cache.
* Fri Apr  4 2025 Jan Engelhardt <jengelh@inai.de>
- Use SRPM base name for devel subpackage
* Tue Apr  1 2025 Mia Herkt <mia@0x0.st>
- Initial package, version 0.11.3
